@@ -1,6 +1,6 @@
 /* Simple Video4Linux image grabber. Made for my Philips Vesta Pro
  * 
- * Copyright (C) 2001, 2002 Jens Gecius, Larchmont, USA
+ * Copyright (C) 2001, 2002 Jens Gecius, Hannover, Germany
  * eMail: devel@gecius.de
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -36,7 +36,7 @@ void usage (char *pname)
 	  " -c <filename>     parse <filename> as config file\n"
 	  " -l <seconds>      Daemonize & sleep <seconds> (min. 1!) between images\n"
 	  " -L <microseconds> Daemonize & sleep <microseconds> between images\n"
-	  " -b                Switch vgrabbj's brightness adjustment (default: off)\n"
+	  " -a                Switch vgrabbj's auto brightness adjustment (default: off)\n"
 	  "                   You might need to set -F 4, too, if it doesn't work\n"
 	  " -q <quality>      Quality setting (%d-%d, default: %d), JPEG only\n"
 	  " -i <sqcif|qsif|qcif|sif|cif|vga|svga|xga|sxga|uxga>\n"
@@ -89,12 +89,14 @@ void usage (char *pname)
 	  " -M <value>        Maximum number of images to keep in archive.\n"
 	  " -E <value>        Take a snapshot for the archive each <value> image.\n"
 	  " -R                Swap left/right like a mirror.\n"
+	  " -U                Swap top/bottom like a mirror.\n"
 	  " -G                Do not use mmap'ed memory - needed only for certain cams\n"
+	  " -X                Do not fork in daemon mode, good for testing/debbuging\n"
 	  "\n"
 	  "Example: %s -l 5 -f /usr/local/image.jpg\n"
 	  "         Would write a single jpeg-image to image.jpg approx. every five seconds\n"
 	  "\n"
-	  "The video stream has to one of RGB24, RGB32, YUV420, YUV420P or YUYV.\n",
+	  "The video stream has to be one of RGB24, RGB32, YUV420, YUV420P or YUYV.\n",
 	  basename(pname), VERSION, basename(pname), MIN_QUALITY, MAX_QUALITY, 
 	  DEFAULT_QUALITY, DEFAULT_WIDTH, DEFAULT_HEIGHT,
 	  DEFAULT_OUTPUT, DEFAULT_VIDEO_DEV, 
@@ -119,7 +121,40 @@ void debug_vconf(struct vconfig *vconf) {
 }  
 #endif
 
+/*
+struct v_options *init_conf_list(struct v_options *conf)
+{
+  struct v_options *list;
+  struct v_options *list_start;
+  int i;
+
+  list=malloc(sizeof(list));
+  list_start=list;
+  for (i=0; l_opt[i].name||l_opt[i].shortname; i++) {
+    list.name=l_opt[i].name;
+    list.short_name=l_opt[i].short_name;
+    list.has_arg=l_opt[i].has_arg;
+    list.var=decode_options(struct vconfig *vconf, char *option, char *value, int o, int n)
+    //decode default options!!!    list.var=l_opt[i].default;
+    list.var_type=l_opt[i].var_type;
+    list.min_value=l_opt[i].min_value;
+    list.max_value=l_opt[i].max_value;
+    list.max_length=l_opt[i].max_length;
+    list.default=l_opt[i].default;
+    list.next=malloc(sizeof(list));
+    list=list.next;
+  }
+  free(list.next);
+  list.next=list_start;
+
+  return (list_start);
+}
+
+    Some development, not release-ready...
+*/
+
 struct vconfig *init_defaults(struct vconfig *vconf) {
+  int idx = 0;
   /* Set defaults */
   vconf->debug      = LOGLEVEL;
   vconf->quality    = DEFAULT_QUALITY;
@@ -129,7 +164,7 @@ struct vconfig *init_defaults(struct vconfig *vconf) {
   vconf->win.height = DEFAULT_HEIGHT;
   vconf->win.width  = DEFAULT_WIDTH;
   vconf->outformat  = DEFAULT_OUTFORMAT;
-  vconf->brightness = DEFAULT_BRIGHTNESS;
+  vconf->autobrightness = DEFAULT_BRIGHTNESS;
   vconf->switch_bgr = FALSE;
   vconf->windowsize = TRUE;
   vconf->loop       = 0;
@@ -143,27 +178,29 @@ struct vconfig *init_defaults(struct vconfig *vconf) {
   vconf->openonce   = TRUE;
   vconf->usetmpout  = TRUE;
   vconf->swaprl     = FALSE;
+  vconf->swaptb     = FALSE;
   vconf->nousemmap  = FALSE;
   vconf->tmpout     = NULL;
   vconf->buffer     = NULL;
   vconf->o_buffer   = NULL;
-  l_opt[0].var = &(int)vconf->debug;
-  l_opt[1].var = &(long int)vconf->loop;
-  l_opt[2].var = &(long int)vconf->loop;
-  l_opt[3].var = &vconf->brightness;
-  l_opt[4].var = &(int)vconf->quality;
-  l_opt[6].var = &vconf->win.width;
-  l_opt[7].var = &vconf->win.height;
-  l_opt[8].var = &(int)vconf->outformat;
-  l_opt[9].var = (char *)vconf->out;
-  l_opt[10].var = (char *)vconf->in;
-  l_opt[11].var = &vconf->openonce;
-  l_opt[12].var = &vconf->switch_bgr;
-  l_opt[13].var = &vconf->windowsize;
-  l_opt[14].var = &(int)vconf->discard;
-  l_opt[15].var = &(int)vconf->forcepal;
-  l_opt[16].var = &vconf->usetmpout;
-  l_opt[17].var = &vconf->use_ts;
+  l_opt[idx++].var  = &(int)vconf->debug;
+  l_opt[idx++].var  = &(long int)vconf->loop;
+  l_opt[idx++].var  = &(long int)vconf->loop;
+  l_opt[idx++].var  = &vconf->autobrightness;
+  l_opt[idx++].var  = &(int)vconf->quality;
+  idx              += 1; /* Image Size */
+  l_opt[idx++].var  = &vconf->win.width;
+  l_opt[idx++].var  = &vconf->win.height;
+  l_opt[idx++].var  = &(int)vconf->outformat;
+  l_opt[idx++].var  = (char *)vconf->out;
+  l_opt[idx++].var  = (char *)vconf->in;
+  l_opt[idx++].var  = &vconf->openonce;
+  l_opt[idx++].var  = &vconf->switch_bgr;
+  l_opt[idx++].var  = &vconf->windowsize;
+  l_opt[idx++].var  = &(int)vconf->discard;
+  l_opt[idx++].var  = &(int)vconf->forcepal;
+  l_opt[idx++].var  = &vconf->usetmpout;
+  l_opt[idx++].var  = &vconf->use_ts;
 #ifdef LIBTTF
   vconf->ttinit     = NULL;
   vconf->font       = strcpy(malloc(strlen(DEFAULT_FONT)+1),DEFAULT_FONT);
@@ -172,12 +209,12 @@ struct vconfig *init_defaults(struct vconfig *vconf) {
   vconf->border     = DEFAULT_BORDER;
   vconf->align      = DEFAULT_ALIGN;
   vconf->blend      = DEFAULT_BLEND;
-  l_opt[18].var = (char *)vconf->font;
-  l_opt[19].var = (char *)vconf->timestamp;
-  l_opt[20].var = &(int)vconf->font_size;
-  l_opt[21].var = &(int)vconf->align;
-  l_opt[22].var = &(int)vconf->blend;
-  l_opt[23].var = &(int)vconf->border;
+  l_opt[idx++].var  = (char *)vconf->font;
+  l_opt[idx++].var  = (char *)vconf->timestamp;
+  l_opt[idx++].var  = &(int)vconf->font_size;
+  l_opt[idx++].var  = &(int)vconf->align;
+  l_opt[idx++].var  = &(int)vconf->blend;
+  l_opt[idx++].var  = &(int)vconf->border;
 #endif
 #ifdef LIBFTP
   vconf->ftp.enable          = FALSE;
@@ -189,26 +226,45 @@ struct vconfig *init_defaults(struct vconfig *vconf) {
   vconf->ftp.username        = NULL;
   vconf->ftp.password        = NULL;
   vconf->ftp.tryharder       = 0;
-  l_opt[24].var = &vconf->ftp.enable;
-  l_opt[25].var = (char *)vconf->ftp.remoteHost;
-  l_opt[26].var = (char *)vconf->ftp.remoteImageName;
-  l_opt[27].var = (char *)vconf->ftp.username;
-  l_opt[28].var = (char *)vconf->ftp.password;
-  l_opt[29].var = &vconf->ftp.keepalive;
-  l_opt[30].var = &(unsigned int)vconf->ftp.tryharder;
-  l_opt[31].var = (char *)vconf->ftp.remoteDir;
+  vconf->ftp.passive	     = FALSE;
+  l_opt[idx++].var  = &vconf->ftp.enable;
+  l_opt[idx++].var  = (char *)vconf->ftp.remoteHost;
+  l_opt[idx++].var  = (char *)vconf->ftp.remoteImageName;
+  l_opt[idx++].var  = (char *)vconf->ftp.username;
+  l_opt[idx++].var  = (char *)vconf->ftp.password;
+  l_opt[idx++].var  = &vconf->ftp.keepalive;
+  l_opt[idx++].var  = &(unsigned int)vconf->ftp.tryharder;
+  l_opt[idx++].var  = (char *)vconf->ftp.remoteDir;
+  l_opt[idx++].var  = &vconf->ftp.passive;
 #endif
-  vconf->archive     = NULL;
-  l_opt[36].var = (char *)vconf->archive;
-  vconf->arch = malloc(sizeof(struct s_arch));
-  vconf->arch->filename=NULL;
-  vconf->arch->next=NULL;
+  idx              += 4;
+  vconf->hue = -1;
+  l_opt[idx++].var  = &(int)vconf->hue;
+  vconf->brightness = -1;
+  l_opt[idx++].var  = &(int)vconf->brightness;
+  vconf->contrast = -1;
+  l_opt[idx++].var  = &(int)vconf->contrast;
+  vconf->colour = -1;
+  l_opt[idx++].var  = &(int)vconf->colour;
+  vconf->whiteness = -1;
+  l_opt[idx++].var  = &(int)vconf->whiteness;
+  vconf->archive    = NULL;
+  l_opt[idx++].var  = (char *)vconf->archive;
+  vconf->arch       = malloc(sizeof(struct s_arch));
+  vconf->arch->filename = NULL;
+  vconf->arch->next = NULL;
   vconf->archiveeach = 0;
   vconf->archivemax = 0;
-  l_opt[37].var = &vconf->archiveeach;
-  l_opt[38].var = &vconf->archivemax;
-  l_opt[39].var = &vconf->swaprl;
-  l_opt[40].var = &vconf->nousemmap;
+  l_opt[idx++].var  = &vconf->archiveeach;
+  l_opt[idx++].var  = &vconf->archivemax;
+  l_opt[idx++].var  = &vconf->swaprl;
+  l_opt[idx++].var  = &vconf->nousemmap;
+  l_opt[idx++].var  = &vconf->swaptb;
+  vconf->nofork     = FALSE;
+  l_opt[idx++].var  = &vconf->nofork;
+  if ( idx != sizeof(l_opt)/sizeof(l_opt[0])-1 ) {
+    v_error(vconf, LOG_CRIT, "Bug in l_opt - contact developer with full debug details.");
+  }
   return vconf;
 }  
 
@@ -269,10 +325,12 @@ struct s_arch *init_archive(struct vconfig *vconf, struct s_arch *archive, int c
   archive=realloc(archive, sizeof(struct s_arch));
   archive->filename=NULL;
   archive->next=NULL;
+  //  v_error(vconf, LOG_DEBUG, "setup of archive structure (%s)",vconf->arch);
   if ( count-->1 )
     archive->next=init_archive(vconf, archive->next, count);
   else
     archive->next=vconf->arch;
+
   return archive;
 }
 
@@ -365,10 +423,13 @@ struct vconfig *check_device(struct vconfig *vconf) {
   v_error(vconf, LOG_DEBUG, "Set palette successfully to %s", plist[vconf->vpic.palette].name);
 
   if ( (ioctl(vconf->dev, VIDIOCGMBUF, &vconf->vbuf) < 0) || 
-       ((vconf->brightness) && (vconf->vpic.palette==VIDEO_PALETTE_RGB24)) ||
+       ((vconf->autobrightness) && 
+	(vconf->vpic.palette==VIDEO_PALETTE_RGB24)) ||
        (vconf->nousemmap) )
     vconf->usemmap=FALSE;
 
+  set_picture_parms(vconf);
+
   if (!vconf->openonce)
     close_device(vconf);
 
@@ -377,20 +438,27 @@ struct vconfig *check_device(struct vconfig *vconf) {
 
 
 void v_update_ptr(struct vconfig *vconf) {
-  vconf->in=(char *)l_opt[10].var;
-  vconf->out=(char *)l_opt[9].var;
+  int i=9;
+  vconf->out=(char *)l_opt[i++].var;
+  vconf->in=(char *)l_opt[i++].var;
+  i=i+7;
 #ifdef LIBTTF
-  vconf->timestamp=(char *)l_opt[19].var;
-  vconf->font=(char *)l_opt[18].var;
+  vconf->font=(char *)l_opt[i++].var;
+  vconf->timestamp=(char *)l_opt[i++].var;
+  i=i+4;
 #endif
 #ifdef LIBFTP
-  vconf->ftp.remoteHost=(char *)l_opt[25].var;
-  vconf->ftp.remoteImageName=(char *)l_opt[26].var;
-  vconf->ftp.username=(char *)l_opt[27].var;
-  vconf->ftp.password=(char *)l_opt[28].var;
-  vconf->ftp.remoteDir=(char *)l_opt[31].var;
+  i++;
+  vconf->ftp.remoteHost=(char *)l_opt[i++].var;
+  vconf->ftp.remoteImageName=(char *)l_opt[i++].var;
+  vconf->ftp.username=(char *)l_opt[i++].var;
+  vconf->ftp.password=(char *)l_opt[i++].var;
+  i++;i++;
+  vconf->ftp.remoteDir=(char *)l_opt[i++].var;
+  i++;
 #endif
-  vconf->archive=(char *)l_opt[36].var;
+  i=i+9;
+  vconf->archive=(char *)l_opt[i].var;
   v_error(vconf, LOG_DEBUG, "Updated pointers to new allocated memory.");
 }
 
@@ -398,6 +466,7 @@ void v_update_ptr(struct vconfig *vconf) {
 
 void decode_options(struct vconfig *vconf, char *option, char *value, int o, int n) {
   int i;
+  
   for (i=0;l_opt[i].name || l_opt[i].short_name; i++) {
     if ( (l_opt[i].name && !strcasecmp(option, l_opt[i].name) && !o) ||  
 	 (l_opt[i].short_name && o==*l_opt[i].short_name) ) {
