@@ -1,6 +1,6 @@
 /* Simple Video4Linux image grabber. Made for my Philips Vesta Pro
  * 
- * Copyright (C) 2001, 2002 Jens Gecius, Larchmont, USA
+ * Copyright (C) 2001, 2002 Jens Gecius, Hannover, Germany
  * eMail: devel@gecius.de
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -175,10 +175,11 @@ void write_image(struct vconfig *vconf) {
 	v_error(vconf, LOG_DEBUG, "Temporary output %s moved to final destination %s", vconf->tmpout, vconf->out);
       if (unlink(vconf->tmpout))
 	v_error(vconf, LOG_ERR, "Couldn't delete %s: %s", vconf->tmpout, strerror(errno));
-    } else
+    } else {
       v_error(vconf, LOG_DEBUG, "Outputfile %s closed", vconf->out);
+    }
 
-    if ((vconf->archive) && (!--vconf->archivecount)) {
+    if ((--vconf->archivecount==0) && (vconf->archive)) {
       /* vconf->archive is a strftime format string, make the final path
        * to archive_path */
       char *ts;
@@ -193,7 +194,7 @@ void write_image(struct vconfig *vconf) {
       }
       vconf->arch->filename=strcpy(realloc(vconf->arch->filename, strlen(ts)),ts);
       v_error(vconf, LOG_DEBUG, "Unlinked old arch-file, realocated new one (%s)", vconf->arch->filename);
-      free(ts);
+      free_ptr(ts);
       vconf->archivecount=vconf->archiveeach;
       vconf->arch=vconf->arch->next;
       v_error(vconf, LOG_DEBUG, "Changed ptr to next filename (%s)", vconf->arch->filename);
