@@ -1,6 +1,6 @@
 /* Simple Video4Linux image grabber. Made for my Philips Vesta Pro
  * 
- * Copyright (C) 2000, 2001, 2002 Jens Gecius, Larchmont, USA
+ * Copyright (C) 2000, 2001, 2002 Jens Gecius, Hannover, Germany
  * eMail: devel@gecius.de
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -207,18 +207,21 @@ unsigned char *read_image(struct vconfig *vconf, int size) {
     if (vconf->windowsize)
       while (ioctl(vconf->dev, VIDIOCSWIN, &vconf->win) )
 	v_error(vconf, LOG_ERR, "Problem setting window size"); // exit
+
+    set_picture_parms(vconf);
   }
-  
+
+
   /* Read image via read() */
 
   if (!vconf->usemmap) {
-    if (vconf->brightness)
+    if (vconf->autobrightness)
       v_error(vconf, LOG_INFO, "Forced to use brightness adj. - using read()");
     else
       v_error(vconf, LOG_INFO, "Could not get mmap-buffer - Falling back to read()");
     do {
       err_count=0;
-      if (vconf->brightness && vconf->vpic.palette==VIDEO_PALETTE_RGB24) {
+      if (vconf->autobrightness && vconf->vpic.palette==VIDEO_PALETTE_RGB24) {
 	v_error(vconf, LOG_INFO, "Doing brightness adjustment");
 	do {
 	  while (read(vconf->dev, vconf->buffer, size) < size)
@@ -346,7 +349,7 @@ int main(int argc, char *argv[])
 
   vconf=v_init(vconf, argc, argv);
 
-  if (vconf->loop) 
+  if (vconf->loop && (!vconf->nofork) ) 
     daemonize(vconf, basename(argv[0]));
   else
     v_error(vconf, LOG_WARNING, "Reading image from %s", vconf->in);
@@ -359,6 +362,9 @@ int main(int argc, char *argv[])
     if (vconf->swaprl) 
       vconf->o_buffer=swap_left_right(vconf->o_buffer, vconf->win.width, vconf->win.height);
 
+    if (vconf->swaptb)
+      vconf->o_buffer=swap_top_bottom(vconf->o_buffer, vconf->win.width, vconf->win.height);
+
 #ifdef LIBTTF
     if (vconf->use_ts) 
       vconf->o_buffer=inserttext(vconf->ttinit, vconf->o_buffer, vconf);
