@@ -1,6 +1,6 @@
 /* Simple Video4Linux image grabber. Made for my Philips Vesta Pro
  * 
- * Copyright (C) 2000, 2001, 2002 Jens Gecius, Larchmont, USA
+ * Copyright (C) 2000, 2001, 2002 Jens Gecius, Hannover, Germany
  * eMail: devel@gecius.de
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -187,9 +187,10 @@ struct vconfig {
   boolean windowsize;
   boolean switch_bgr;
   boolean use_ts;
-  boolean brightness;
+  boolean autobrightness;
   boolean init_done;
   boolean swaprl;
+  boolean swaptb;
   boolean nousemmap;
   int inputnorm;
   int channel;
@@ -209,7 +210,13 @@ struct vconfig {
   struct video_capability vcap;
   struct video_mmap vmap;
   struct video_mbuf vbuf;
+  int hue;
+  int brightness;
+  int contrast;
+  int colour;
+  int whiteness;
   char *map;
+  boolean nofork;
 #ifdef LIBFTP
   struct FTP {
     boolean enable;
@@ -221,6 +228,7 @@ struct vconfig {
     char *password;
     unsigned int state;
     unsigned int tryharder;
+    boolean passive;
   }ftp;
 #endif
 };
@@ -241,6 +249,8 @@ struct v_options {
   int min_value;
   int max_value;
   int max_length;
+  const char *standard;
+  struct v_options *next;
 };
 
 struct v_out_type {
@@ -290,6 +300,7 @@ extern unsigned char  *switch_color(struct vconfig *vconf);
 extern void            init_mmap(struct vconfig *vconf);
 extern void            free_mmap(struct vconfig *vconf);
 extern void            open_device(struct vconfig *vconf);
+extern int             set_picture_parms(struct vconfig *vconf);
 extern void            close_device(struct vconfig *vconf);
 extern void            cleanup(struct vconfig *vconf);
 extern int             signal_terminate;
@@ -303,6 +314,7 @@ extern FILE           *open_outfile(char *filename);
 extern char           *timestring(char *format);
 extern struct vconfig *parse_config(struct vconfig *vconf);
 extern unsigned char  *swap_left_right(char *buffer, int width, int height);
+extern unsigned char  *swap_top_bottom(char *buffer, int width, int height);
 
 #ifdef LIBTTF
 extern void      Face_Done   (TT_Instance inst, TT_Face face);
